# brawlpython
 
Easy-to-configure library to use any Brawl Stars API

[project link](https://github.com/0dminnimda/brawlpython)

use a token instead of a password, look at the change in the version and content of the project on the testpipe
